searchData={"items":[{"type":"module","title":"ExYUV","doc":"# ExYUV\n\nElixir binding for [libyuv](https://chromium.googlesource.com/libyuv/libyuv/).\n\nlibyuv is an open source project that includes YUV scaling and conversion functionality.\n\n  * Scale YUV to prepare content for compression, with point, bilinear or box filter.\n  * Convert to YUV from webcam formats for compression.\n  * Convert to RGB formats for rendering/effects.\n  * Rotate by 90/180/270 degrees to adjust for mobile devices in portrait mode.\n  * Optimized for SSSE3/AVX2 on x86/x64.\n  * Optimized for Neon/SVE2/SME on Arm.\n  * Optimized for MSA on Mips.\n  * Optimized for RVV on RISC-V.","ref":"ExYUV.html"},{"type":"module","title":"Formats - ExYUV","doc":"Formats (FOURCC) supported by libyuv are detailed here.","ref":"ExYUV.html#module-formats"},{"type":"module","title":"Core Formats - ExYUV","doc":"There are 2 core formats supported by libyuv - `I420` and `ARGB`. All YUV formats can be converted to/from `I420`. All `RGB` formats can be converted to/from `ARGB`.\n\nFiltering functions such as scaling and planar functions work on `I420` and/or `ARGB`.","ref":"ExYUV.html#module-core-formats"},{"type":"module","title":"Planar Formats - ExYUV","doc":"| Format | Planes | Description |\n|--------|--------|-------------|\n| `I420` | 3      | Y full resolution. U half width, half height. V half width, half height |","ref":"ExYUV.html#module-planar-formats"},{"type":"module","title":"Packed Formats - ExYUV","doc":"| Format | Bits Per Pixel | Pixel Memory Layout |\n|--------|---------------|---------------|\n| `RAW` (RGB) | 24       | `< >` |\n| `RGB24` | 24           | `< >` |\n| `ARGB`  | 32           | `< >` |\n| `ABGR`  | 32           | `< >` |\n| `BGRA`  | 32           | `< >` |\n| `RGBA`  | 32           | `< >` |\n| `RGB565`| 16           | `< >` |\n| `RGB1555`| 16          | `< >` |\n| `RGB4444`| 16          | `< >` |\n| `AR30`  | 32          | `< >` |\n| `AB30`  | 32          | `< >` |","ref":"ExYUV.html#module-packed-formats"},{"type":"module","title":"Installation - ExYUV","doc":"The package can be installed by adding `ex_yuv` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_yuv, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"ExYUV.html#module-installation"},{"type":"type","title":"ExYUV.argb_16/0","doc":"","ref":"ExYUV.html#t:argb_16/0"},{"type":"type","title":"ExYUV.argb_32/0","doc":"","ref":"ExYUV.html#t:argb_32/0"},{"type":"type","title":"ExYUV.filter_mode/0","doc":"","ref":"ExYUV.html#t:filter_mode/0"},{"type":"type","title":"ExYUV.height/0","doc":"","ref":"ExYUV.html#t:height/0"},{"type":"type","title":"ExYUV.i420_data/0","doc":"","ref":"ExYUV.html#t:i420_data/0"},{"type":"function","title":"ExYUV.i420_to_ab30!/3","doc":"Convert I420 to AB30.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_ab30!/3"},{"type":"function","title":"ExYUV.i420_to_abgr!/3","doc":"Convert I420 to ABGR.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_abgr!/3"},{"type":"function","title":"ExYUV.i420_to_ar30!/3","doc":"Convert I420 to AR30.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_ar30!/3"},{"type":"function","title":"ExYUV.i420_to_argb1555!/3","doc":"Convert I420 to ARGB1555.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_argb1555!/3"},{"type":"function","title":"ExYUV.i420_to_argb4444!/3","doc":"Convert I420 to ARGB4444.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_argb4444!/3"},{"type":"function","title":"ExYUV.i420_to_argb!/3","doc":"Convert I420 to ARGB.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_argb!/3"},{"type":"function","title":"ExYUV.i420_to_bgra!/3","doc":"Convert I420 to BGRA.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_bgra!/3"},{"type":"function","title":"ExYUV.i420_to_raw!/3","doc":"Converts from I420 to RGB24 format.\n\nThe input should be the planes (Y, U and V), in case a binary is\nprovided, it'll try to get the planes from it.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_raw!/3"},{"type":"function","title":"ExYUV.i420_to_rgb24!/3","doc":"Convert I420 to BGR24.\n\n>","ref":"ExYUV.html#i420_to_rgb24!/3"},{"type":"function","title":"Note - ExYUV.i420_to_rgb24!/3","doc":">\n> Even when the function name hints that the output format is RGB24, it's\n> actually BGR24.\n> We kept the same naming convention used in `libyuv`.","ref":"ExYUV.html#i420_to_rgb24!/3-note"},{"type":"function","title":"ExYUV.i420_to_rgb565!/3","doc":"Convert I420 to RGB565.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_rgb565!/3"},{"type":"function","title":"ExYUV.i420_to_rgba!/3","doc":"Convert I420 to RGBA.\n\nThe memory layout of the result is `< >`","ref":"ExYUV.html#i420_to_rgba!/3"},{"type":"function","title":"ExYUV.raw_to_i420!/3","doc":"Converts from RGB24 to I420 format.","ref":"ExYUV.html#raw_to_i420!/3"},{"type":"type","title":"ExYUV.rgb_16/0","doc":"","ref":"ExYUV.html#t:rgb_16/0"},{"type":"type","title":"ExYUV.rgb_24/0","doc":"","ref":"ExYUV.html#t:rgb_24/0"},{"type":"function","title":"ExYUV.scale_argb!/6","doc":"Scale ARGB/ABGR/RGBA/BGRA image.\n\nThe following filters are supported: `none`, `linear`, `bilinear`, and `box`.\n\nCheck [libyuv](https://chromium.googlesource.com/libyuv/libyuv/+/refs/heads/main/docs/filtering.md) documentation for more details.","ref":"ExYUV.html#scale_argb!/6"},{"type":"function","title":"ExYUV.scale_i420!/6","doc":"Scale I420 image.\n\nThe following filters are supported: `none`, `linear`, `bilinear`, and `box`.\n\nCheck [libyuv](https://chromium.googlesource.com/libyuv/libyuv/+/refs/heads/main/docs/filtering.md) documentation for more details.","ref":"ExYUV.html#scale_i420!/6"},{"type":"function","title":"ExYUV.scale_rgb!/6","doc":"Scale RAW/RGB24 image.\n\nThe following filters are supported: `none`, `linear`, `bilinear`, and `box`.\n\nCheck [libyuv](https://chromium.googlesource.com/libyuv/libyuv/+/refs/heads/main/docs/filtering.md) documentation for more details.","ref":"ExYUV.html#scale_rgb!/6"},{"type":"type","title":"ExYUV.u_plane/0","doc":"","ref":"ExYUV.html#t:u_plane/0"},{"type":"type","title":"ExYUV.v_plane/0","doc":"","ref":"ExYUV.html#t:v_plane/0"},{"type":"type","title":"ExYUV.width/0","doc":"","ref":"ExYUV.html#t:width/0"},{"type":"type","title":"ExYUV.y_plane/0","doc":"","ref":"ExYUV.html#t:y_plane/0"},{"type":"type","title":"ExYUV.yuv_planes/0","doc":"","ref":"ExYUV.html#t:yuv_planes/0"},{"type":"extras","title":"ExYUV","doc":"# ExYUV\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_yuv.svg)](https://hex.pm/packages/ex_yuv)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_yuv)\n\nElixir binding for [libyuv](https://chromium.googlesource.com/libyuv/libyuv/).\n\nlibyuv is an open source project that includes YUV scaling and conversion functionality.\n\n  * Scale YUV to prepare content for compression, with point, bilinear or box filter.\n  * Convert to YUV from webcam formats for compression.\n  * Convert to RGB formats for rendering/effects.\n  * Rotate by 90/180/270 degrees to adjust for mobile devices in portrait mode.\n  * Optimized for SSSE3/AVX2 on x86/x64.\n  * Optimized for Neon/SVE2/SME on Arm.\n  * Optimized for MSA on Mips.\n  * Optimized for RVV on RISC-V.","ref":"readme.html"},{"type":"extras","title":"Formats - ExYUV","doc":"Formats (FOURCC) supported by libyuv are detailed here.","ref":"readme.html#formats"},{"type":"extras","title":"Core Formats - ExYUV","doc":"There are 2 core formats supported by libyuv - `I420` and `ARGB`. All YUV formats can be converted to/from `I420`. All `RGB` formats can be converted to/from `ARGB`.\n\nFiltering functions such as scaling and planar functions work on `I420` and/or `ARGB`.","ref":"readme.html#core-formats"},{"type":"extras","title":"Planar Formats - ExYUV","doc":"| Format | Planes | Description |\n|--------|--------|-------------|\n| `I420` | 3      | Y full resolution. U half width, half height. V half width, half height |","ref":"readme.html#planar-formats"},{"type":"extras","title":"Packed Formats - ExYUV","doc":"| Format | Bits Per Pixel | Pixel Memory Layout |\n|--------|---------------|---------------|\n| `RAW` (RGB) | 24       | `< >` |\n| `RGB24` | 24           | `< >` |\n| `ARGB`  | 32           | `< >` |\n| `ABGR`  | 32           | `< >` |\n| `BGRA`  | 32           | `< >` |\n| `RGBA`  | 32           | `< >` |\n| `RGB565`| 16           | `< >` |\n| `RGB1555`| 16          | `< >` |\n| `RGB4444`| 16          | `< >` |\n| `AR30`  | 32          | `< >` |\n| `AB30`  | 32          | `< >` |","ref":"readme.html#packed-formats"},{"type":"extras","title":"Installation - ExYUV","doc":"The package can be installed by adding `ex_yuv` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_yuv, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}